function Error_grad ()
% Fonction de test avec calcul réel de gradient.

size_x = 512;
size_y = 512;
im_size = [size_y, size_x];
center_x = size_x/2 + .5;
center_y = size_y/2 + .5;
center = [center_x; center_y];

param = GetDefaultParameters();

mask = myInitializeMask( im_size );

distance_max = 200;
space = ceil(distance_max / (2*pi)):5:center_y-3;

dataname = 'real_';

% Nombre de figure à tracer
n_fig = 8;

    for nb_fig = 1:n_fig
        param = GetDefaultParameters();
        
        % Parametres communs à toutes les figures
        dumname = '_processMedian_bilinear';
        param.grad.processing_method = 'median';
        param.grad.interpolation_method = 'bilinear';
        switch(nb_fig)
            % Paramètres particuliers à chaque figure
            case 1
                param.computeline.method = 'runge-kutta-45';
                nomfichier = sprintf('data/%scirc_%s%s.data', dataname, param.computeline.method, dumname);
                
            case 2
                param.computeline.method = 'runge-kutta-45';
                param.im.correlation = 1;
                nomfichier = sprintf('data/%scirc_%s_corel%s.data', dataname, param.computeline.method, dumname);
                
            case 3
                param.computeline.method = 'runge-kutta-45';
                param.im.median = 1;
                nomfichier = sprintf('data/%scirc_%s_median%s.data', dataname, param.computeline.method, dumname);
                
            case 4
                param.computeline.method = 'runge-kutta-45';
                param.im.wiener = 1;
                nomfichier = sprintf('data/%scirc_%s_wiener%s.data', dataname, param.computeline.method, dumname);
                
            case 5
                param.computeline.method = 'runge-kutta-45';
                param.im.correlation = 1;
                param.im.wiener = 1;
                nomfichier = sprintf('data/%scirc_%s_corel_wiener%s.data', dataname, param.computeline.method, dumname);
                
            case 6
                param.computeline.method = 'runge-kutta-45';
                param.im.correlation = 1;
                param.im.median = 1;
                nomfichier = sprintf('data/%scirc_%s_corel_median%s.data', dataname, param.computeline.method, dumname);
                
            case 7
                param.computeline.method = 'runge-kutta-45';
                param.im.median = 1;
                param.im.wiener = 1;
                nomfichier = sprintf('data/%scirc_%s_median_wiener%s.data', dataname, param.computeline.method, dumname);
                
            case 8
                param.computeline.method = 'runge-kutta-45';
                param.im.correlation = 1;
                param.im.median = 1;
                param.im.wiener = 1;
                nomfichier = sprintf('data/%scirc_%s_corel_median_wiener%s.data', dataname, param.computeline.method, dumname);
        end
        
        figure(nb_fig);
        imshow('002.png'); hold on;
        plot_circle( center, space, distance_max, 200 );
        
        [error, lines] = errors_grad( param, mask, im_size, distance_max, space );
        disp_lines( lines, param.display.linespec );
        print_tikz_error( error, nomfichier );
        title( sprintf('%s (%s)', param.computeline.method, nomfichier) );
        fprintf('\n');
        
    end

    figure;

end

%% ------- -- -- -  -                                      -  - -- -- --------%%
%---- -- -  -                  FONCTIONS LOCALES                   -  - -- ----%
%%-------- -- -- -  -                                      -  - -- -- ------- %%

function [error, line] = calc_grad_line( param, mask, im_size, distance_max, rayon )
[I, center] = make_circular_image( im_size, distance_max, rayon );
grad = InterpolateImage( I, param );
grad = ProcessImage( grad, param );
grad = ComputeGradient( grad, param );
grad = ProcessGradient( grad, param );

x_0 = center + [ 2; -rayon ];
line = ComputeLine(x_0, grad, mask, param);

linefoo = line - repmat( center, 1, size(line, 2) );
% Norme L1 vvv
foo = abs(sqrt(linefoo(1,:).^2 + linefoo(2,:).^2) - rayon);
linesize = sqrt( ( linefoo(1,2:end) - linefoo(1,1:end-1) ).^2 + ...
                                       ( linefoo(2,2:end) - linefoo(2,1:end-1) ).^2 );
error = sum( linesize .* foo(2:end) ) / sum(linesize); 
end

%% --------- ---- -  -                                    -  - ---- --------- %%

function [ errors, lines ] = errors_grad( param, mask, im_size, distance_max, space )
    errors = zeros(length(space),2);
    lines = cell(length(space),1);
    k = 1;
    for rayon = space
        [dum_error, dum_line] = calc_grad_line( param, mask, im_size, distance_max, rayon );
        errors(k,1) = rayon;
        errors(k,2) = dum_error;
        lines{k} = dum_line;
        k = k+1;
    end
end

%% --------- ---- -  -                                    -  - ---- --------- %%

function plot_circle( center, space, dmax, nb_point )
  for rayon = space
    line = zeros( nb_point, 2 );
    i = 1;
    for angle = linspace( 0, min(2*pi,dmax / rayon), nb_point );
        line(i,1) = center(1) + rayon*cos(angle-pi/2);
        line(i,2) = center(2) + rayon*sin(angle-pi/2);
        i = i+1;
    end
    plot( line(:,1)+.5, line(:,2)+.5, '-g' );
  end
end

%% --------- ---- -  -                                    -  - ---- --------- %%

function disp_lines( lines, color )
    for i = 1:length(lines)
        line = lines{i};
        line = line + 0.5;
        plot(line(1,:), line(2,:), color);
    end
end

%% --------- ---- -  -                                    -  - ---- --------- %%

function m = myInitializeMask( im_size )    
    m.continue = ones( im_size );
    m.start = ones( im_size );
end

%% --------- ---- -  -                                    -  - ---- --------- %%

function print_tikz_error( error, nom )

    fileID = fopen(nom, 'w');
    for i = 1:size(error,1)
        fprintf(fileID, '%2.6f\t%2.6f\n', error(i,1), error(i,2));
    end
    fclose( fileID );

end
