function grad = ComputeGradient(im, param)
    % grad contains the gradient of im, according to param.
    % size(grad) ~ (size(im) * param.grad_ratio)x2
    % param :
    %       param.grad.ratio    : double (typically, 1...)
    %       param.grad.operator : nxnx2 (x-y), local correlation filter ?
    %       param.grad.method   = {'correlation', 'fourier'}
    % Author : Jean Feydy
    
    
    if strcmp(param.grad.method, 'correlation')
        ComputeGradientCorrelation();
    end;
    
    
    
    function ComputeGradientCorrelation()
        % Compute the gradient by applying param.grad.operator as a filter
        % Reminder : param.grad.operator(:,:,1) ~ d/dx, 
        %            param.grad.operator(:,:,2) ~ d/dy
        grad(:,:,1) = imfilter(im, param.grad.operator(:,:,1), 'replicate');
        grad(:,:,2) = imfilter(im, param.grad.operator(:,:,2), 'replicate');
    end
end