function DispBackgroundImage(im, param)
    % Disp the Background Image, according to param.
    %
    %   param :
    %       param.background.image = { 'none',
    %           'original image',
    %           'interpolated image', 'processed image',
    %           'start mask',
    %           'gradient', 'null gradient', 'below-threshold gradient'}
    %
    % Author : Jean Feydy
    
    if strcmp(param.background.image, 'original image')
        im_disp = mat2gray(im);
    elseif strcmp(param.background.image, 'interpolated image')
        im = InterpolateImage(im, param);
        im_disp = mat2gray(im);
    elseif strcmp(param.background.image, 'processed image')
        im = InterpolateImage(im, param);
        im = ProcessImage(im, param);
        im_disp = mat2gray(im);  
    elseif strcmp(param.background.image, 'start mask')
        im = InterpolateImage(im, param);
        im = ProcessImage(im, param);
        gr = ComputeGradient(im, param);
        gr = ProcessGradient(gr, param);
        m = InitializeMask(im, gr, param);
        im_disp = mat2gray(m.start);   
    elseif strcmp(param.background.image, 'gradient')
        im_disp = ComputeGradient(im, param);
        im_disp = sqrt(im_disp(:,:,1).^2 + im_disp(:,:,2).^2);
        im_disp = mat2gray(im_disp);
    elseif strcmp(param.background.image, 'null gradient')
        im_disp = ComputeGradient(im, param);
        im_disp = mat2gray(im_disp == 0);
    elseif strcmp(param.background.image, 'below-threshold gradient')
        im_disp = ComputeGradient(im, param);
        im_disp = mat2gray(im_disp <= param.computeline.stopping.grad_norm_threshold);
    end;
    if ~strcmp(param.background.image, 'none')
        image(im_disp(:,:,[1 1 1]));
    end;
end