function [lines, grad] = GetGradientLines(im, param)
    % Returns gradient lines (encoded as a set of lists of points)
    %
    %   param :
    %       param.n_lines : int
    %           The max number of gradient lines we draw.
    % Author : Jean Feydy
    
    % We typically work with a supsampled, blurred version of the original
    % image.
    im = InterpolateImage(im, param);
    im = ProcessImage(im, param);
    
    % We typically work with a regularized gradient.
    % At first, let's restrict ourselves to grad_ratio = 1,
    % i.e. size(grad) ~ size(im) x 2
    grad = ComputeGradient(im, param);
    grad = ProcessGradient(grad, param);
    
    mask = InitializeMask(im, grad, param);
    
    lines = {}; % each element of lines is a 2xn_i float vector,
                % n_i is the length of the line
      
    while 1
        if numel(lines) >= param.n_lines % Stopping criterion
            break;
        end;
        try
            [x_0, mask] = GetNewStartingPoint(im, grad, mask, param);
            [line, mask] = ComputeLine(x_0, grad, mask, param);
                % N.B. : line points are mainly float, pointing outside of the
                % regular grid.
            lines = [lines, line];
            
        catch ME
            if strcmp(ME.identifier, 'GRADLINES:GetNewStartingPoint:NoNewStartingPoint')
                sprintf('\nNo new starting point can be found.\n');
                break;
            else
                rethrow(ME)
            end;
        end;
        if isequal(mod(numel(lines), 50), 0) % Fancy printing...
            fprintf('\n');
        end;
    end;
    fprintf('\n');
end