function grad = Make_circle_gradient( im, type, rayon )
% Construit un gradient idéal :
%  - type = 'circ' [gradient circulaire]
%  - type = 'radial' [gradient radial]
% Le paramètre 'rayon' permet de fixer la longueur des lignes de gradient à
% '2*pi*rayon'  (la ligne de gradient de rayon 'rayon' est la première
% ligne de gradient (qui est alors fermée)).

    if nargin < 2
        type = 'circ';
    end
    
    if nargin < 3
        rayon = inf;
    end

    switch type
        case 'circ'
            [ size_y, size_x, ~ ] = size( im );
            center_x = size_x/2 + .5;
            center_y = size_y/2 + .5;

            grad = zeros( size_y, size_x, 2 );
            [grad(:,:,1), grad(:,:,2)] = meshgrid( 1:size_x, 1:size_y );

            foo = -(grad(:,:,2) - center_y);
            grad(:,:,2) = (grad(:,:,1) - center_x);
            grad(:,:,1) = foo;

            norm = sqrt(grad(:,:,1).^2 + grad(:,:,2).^2);
            norm(norm == 0) = 1;
            grad(:,:,1) = grad(:,:,1) ./ norm;
            grad(:,:,2) = grad(:,:,2) ./ norm;

            grad(1:floor(center_y),floor(center_x):ceil(center_x),1) = 0;
            grad(1:floor(center_y),floor(center_x):ceil(center_x),2) = 0;
            
            [XX,YY] = meshgrid( 1:size_x, 1:size_y );
            XX = XX - center_x;
            YY = YY - center_y;
            angle = atan2( YY, XX );
            angle = mod(angle + (pi/2),2*pi);
            
            foo = grad(:,:,1);    foo( angle.*norm > rayon ) = 0;    grad(:,:,1) = foo;
            foo = grad(:,:,2);    foo( angle.*norm > rayon ) = 0;    grad(:,:,2) = foo;
            
        case 'radial'
            [ size_y, size_x, ~ ] = size( im );
            center_x = size_x/2 + .5;
            center_y = size_y/2 + .5;
            thres = center_x - .5;

            grad = zeros( size_y, size_x, 2 );
            [grad(:,:,1), grad(:,:,2)] = meshgrid( 1:size_x, 1:size_y );

            foo = grad(:,:,1) - center_x;
            grad(:,:,2) = grad(:,:,2) - center_y;
            grad(:,:,1) = foo;

            norm = sqrt(grad(:,:,1).^2 + grad(:,:,2).^2);

            foo = grad(:,:,1);    foo(norm>thres) = 0;    grad(:,:,1) = foo;
            foo = grad(:,:,2);    foo(norm>thres) = 0;    grad(:,:,2) = foo;
            
            norm(norm == 0) = 1;
            grad(:,:,1) = grad(:,:,1) ./ norm;
            grad(:,:,2) = grad(:,:,2) ./ norm;
            
        otherwise
            error('unknown argument\n');
    end
end