function [I, center] = make_circular_image( size_I, distance, rayon )
% Construit une image de gradient circulaire donc la ligne de gradient de
% rayon 'rayon' a une distance égale à 'distance'.


    if nargin < 2
        distance = 2*pi;
        rayon = 1;
    end
    
    angle_max = distance / rayon;
    
    size_y = size_I(1);
    size_x = size_I(2);
    center_x = size_x/2 + .5;
    center_y = size_y/2 + .5;
    center = [center_x; center_y];
    
    [Ix, Iy] = meshgrid( 1:size_x, 1:size_y );

    Ix = Ix - center_x;
    Iy = Iy - center_y;
    I = atan2( Iy, Ix );
    I = mod(I + (pi/2),2*pi);
    
    I( I >= pi + (angle_max / 2) ) = 0; 
    
    I = max( min( floor( 256/(angle_max) * I ), 255), 0);
    
end